<?php
/**
 * Gestion du formulaire de configuration du plugin Subdivisions Géographiques
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GPL 3
 * @package    SPIP\Subdivisions\Formulaires
 */


if (!defined('_ECRIRE_INC_VERSION')) return;
 

/**
 * Description des saisies du formulaire de configuration
 *
 * @link : https://contrib.spip.net/Formulaire-de-configuration-avec-le-plugin-Saisies
 *
 * La présente définition offre des saisies pour :
 * - permettre le peuplement de l'objet éditorial si le plugin Nomenclatures Officielles
 *   a partagé ses données ;
 * - permettre de définir les associations de l'objet éditorial
 *
 * @return array
 *     Description des saisies
 */
function formulaires_configurer_subdivisions_saisies_dist(){

	// Vérifier la présence de la table spip_iso3166subdivisions
	
	$trouver_table = charger_fonction('trouver_table', 'base');
	$desc = $trouver_table('spip_iso3166subdivisions');
	if ($desc) {
		$hidden = array( 
					'saisie' => 'hidden',
					'options' => array(
					'nom' => 'spip_iso3166subdivisions',
					'defaut' => 'présente'
					));
	} else {
		$hidden = array( 
					'saisie' => 'hidden',
					'options' => array(
					'nom' => 'spip_iso3166subdivisions',
					'defaut' => 'absente'
					));
	}
	
	// selon l'existence du plugin Pays et de sa saisie, nourrir la saisie de choix d'un pays pour le peuplement.

	if (test_plugin_actif('pays')) {
		$carte_donnees = charger_fonction('subdivisions_verifier', 'base');
		$ma_situation = $carte_donnees();
		$datas = array();
		foreach ($ma_situation as $iso_code => $afaire) {
			$nom = sql_getfetsel(
				sql_multi ("nom", $GLOBALS['spip_lang']),
				'spip_pays', 
				'code=' . sql_quote($iso_code)
			);
			$datas[$iso_code] =  $nom ." ($iso_code)";
			if ($afaire != 'on') {
				$defaut .= $iso_code . ',';
			}
		}
		if ($disable_choix) {
			$disable_choix = substr($disable_choix, 0, -1);
		}
		
		$pays =	array(
			'saisie' => 'checkbox',
			'options' => array(
				'nom' => 'iso_pays',
				'afficher_si' => '@tous@ !="on" && @spip_iso3166subdivisions@ == "présente"',
				'label' => _T('subdivision:config_peuplement_iso_pays'),
				'explication' => _T('subdivision:config_peuplement_pays_explication'),
				'datas' => $datas,
				'defaut' => $defaut
			)
		);
	} else {
		$carte_donnees = charger_fonction('subdivisions_verifier', 'base');
		$ma_situation = $carte_donnees();
		$datas = array();
		foreach ($ma_situation as $iso_code => $afaire) {
			$datas[$iso_code] = $iso_code;
			if ($afaire != 'on') {
				$defaut .= $iso_code . ',';
			}
		}
		if ($disable_choix) {
			$disable_choix = substr($disable_choix, 0, -1);
			$defaut = substr($defaut, 0, -1);
		}

		$pays =	array(
			'saisie' => 'checkbox',
			'options' => array(
				'nom' => 'iso_pays',
				'afficher_si' => '@tous@ !="on" && @spip_iso3166subdivisions@ == "présente"',
				'label' => _T('subdivision:config_peuplement_iso_pays'),
				'explication' => _T('subdivision:config_peuplement_iso_pays_explication'),
				'datas' => $datas,
				'defaut' => $defaut
			)
		);
	}

	$saisies = array(
		array( // le fieldset de peuplement de la table
			'saisie' => 'fieldset',
			'options' => array(
				'nom' => 'peuplement',
				'label' => _T('subdivision:config_peuplement_fieldset'),
				'icone' => 'prive/themes/spip/images/base-32.png',
			),
    		'saisies' => array( // les champs dans le fieldset 
				$hidden,
				array(
					'saisie' => 'explication',
					'options' => array (
						'afficher_si' => '@spip_iso3166subdivisions@ == "absente"',
						'nom' => 'utilise_isocode',
						'titre' => _T('subdivision:config_peuplement_isocode'),
						'texte' => _T('subdivision:config_peuplement_isocode_installation_explication'),
						'conteneur_class' => 'pleine_largeur'
					)
				),
				array(
					'saisie' => 'explication',
					'options' => array (
						'afficher_si' => '@spip_iso3166subdivisions@ == "présente"',
						'nom' => 'utilise_isocode',
						'titre' => _T('subdivision:config_peuplement_isocode'),
						'texte' => _T('subdivision:config_peuplement_isocode_utilise_explication'),
						'conteneur_class' => 'pleine_largeur'
					)
				),
				array(
					'saisie' => 'case',
					'options' => array(
						'afficher_si' => '@spip_iso3166subdivisions@ == "présente"',
						'nom' => 'tous',
						'label' => _T('subdivision:config_peuplement_tous'),
						'label_case' => _T('subdivision:config_peuplement_tous')
					)
				),
				$pays,
			)
		),
		array( // le fieldset de vie ordinaire de l'objet
			'saisie' => 'fieldset',
			'options' => array(
				'nom' => 'vie',
				'label' => _T('subdivision:config_peuplement_vie'),
				'icone' => 'prive/themes/spip/images/configuration-32.png',
			),
    		'saisies' => array( // les champs dans le fieldset 
				array(
					'saisie' => 'choisir_objets',
					'options' => array (
						'nom' => 'association_subdivision_objets',
						'label' => _T('subdivision:config_association_subdivision_objets'),
						'explication' => _T('subdivision:config_association_subdivision_objets_explication'),
						'exclus' => array('spip_subdivisions','spip_gis')
					)
				)
			)
		)
	);
	return $saisies;
}

