<?php

/**
 * API pour gérer l'installation et la desinstallation des données
 * de l'objet éditorial Subdivision
 *
 * Cette API interroge les tables pertinentes
 * et peuple ou vide la table de l'objet éditorial en conséquence.
 *
 * API à utiliser :
 *     ```
 *     include_spip('inc/apisubdivision');
 *     ```
 * @plugin     Subdivisions Géographiques
 * @copyright  2019-2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\inc
 */

// Sécurité
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Vérification de la disponibilité des données pour un peuplement
 *
 * @api
 * @use API « editer_objet »
 *      interface de programmation pour l’ajout, la modification et la publication des instances d’objets éditoriaux
 * @use subdivisions_verifier
 *      fonction surchargeable côté donnée, appelant l'API de Nomenclatures Officielles
 * @param void (à faire si pertinent)
 * @return bool|array
 *     - false si la subdivision ou le code ISO n'a pas de forme géométrique disponible en Open Data.
 *       - [id_subdivision_api] clé primaire de la table spip_subdivisions_apis, si on y trouve l'API Open Data pertinente
 *		 - [id_subdivision] clé primaire de la table spip_subdivisions.
 */

function apisubdivision_peuplement (){

	// Ce que l'utilisateur demande 
		
	$choix = lire_config('subdivisions/iso_pays');
	$tous = lire_config('subdivisions/tous');
		
	// Ce qui est peuplé
		
	$carte_donnees = charger_fonction('subdivisions_verifier', 'base');
	$cartographie = $carte_donnees();


	if ($tous == "on") {
		$choix = $cartographie;
		$choix = array_map(function($val) { return 'demandé'; }, $choix);
	} else {
		$choix = array_flip($choix);
		$choix = array_map(function($val) { return 'demandé'; }, $choix);
	}

	$isocode_donnees = charger_fonction('subdivisions_charger', 'base');

	// Le traitement
	
	$explication='';
	include_spip('action/editer_objet');
	
	foreach ($cartographie as $iso_pays => $bdd) {
		if ( $choix[$iso_pays] == "demandé" AND $bdd == "disponible" ) { // mise à jour demandée et possible
			$explication.= "<br />" . _T('subdivision:api_expli_peupler', array('pays'=>$iso_pays)); 
			$les_donnees = $isocode_donnees($iso_pays);
			list($schema, $donnees) = $les_donnees;
			unset($les_donnees);
			if ($donnees) {
				foreach ($donnees['subdivisions'] as $champs) {
					// nom_usage, date, statut, maj
					$champs = array_merge ($champs, array(
							'nom_usage' => $champs['iso_titre'],
					 		'date' => date('Y-m-d H:i:s'),
					 		'statut' => 'publie',
					 		'maj' =>  date('Y-m-d H:i:s')
					 	)
					);
					$id_subdivisions = objet_inserer('subdivision', '', $champs);
				}
			// on enregistre le versionnage
			$champs = array (
				'iso_pays' => $iso_pays,
				'isocode_schema' => $schema,
				'maj' => date('Y-m-d H:i:s')
			);
			$id = sql_insertq('spip_subdivisions_schemas', $champs);
			}
		} elseif ( $bdd == "installé" AND !$choix[$iso_pays]) { // installées mais pas demandées = vider
			$explication.= "<br />" . _T('subdivision:api_expli_vider', array('pays'=>$iso_pays)); 
			sql_delete("spip_subdivisions", "iso_pays=" . sql_quote($iso_pays));
			sql_delete("spip_subdivisions_schemas", "iso_pays=" . sql_quote($iso_pays));
		}
	}
return $explication;
}

/**
 * Retablir ou faire les liaisons après une modification de la base
 *
 * @api
 * @param int|string $id_subdivision|$code_iso
 *     Identifiant unique de la subdivision ou Code ISO
 * @return bool|int
 *     - false si la subdivision ou le code ISO n'a pas de liaison.
 *     - clé primaire de la table et nom de celle-ci.
 */

function apisubdivision_liaisons ($argument){
	// à faire
	
	return false;
}



