<?php
/**
 * Définit les pipelines utilisés par le plugin Subdivisions Géographiques
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Pipelines
 */

if (!defined("_ECRIRE_INC_VERSION")) return;


/**
 * Ajout de contenu sur les objets.
 * 
 * Contenus :
 * - formulaire de liaisons entre les auteurs et les subdivisions
 * - formulaire de liaisons entre les subdivisions et les objets reconnus dans sa configuration
 *
 * @pipeline affiche_milieu
 * @param  array $flux Données du pipeline
 * @return array       Données du pipeline
 */
function subdivisions_affiche_milieu($flux) {
	$texte = '';
	$e = trouver_objet_exec($flux['args']['exec']);
	$table = table_objet_sql($flux['args']['exec']);

	// Des auteurs associés aux subdivisions...
	if (!$e['edition'] and in_array($e['type'], array('subdivision'))) {
		//... associer des auteurs (donnez des rôles aux auteurs vis-à-vis des subdivisions !)
		$texte .= recuperer_fond('prive/objets/editer/liens', array(
			'table_source' => 'auteurs',
			'objet' => $e['type'],
			'id_objet' => $flux['args'][$e['id_table_objet']],
	        'editable'=>autoriser('associerauteurs',$e['type'],$flux['args'][$e['id_table_objet']])?'oui':'non'
		));
	}
	// Des subdivisions associées aux objets éditoriaux sélectionnés dans la configuration du plugin 
	// ('régionaliser' vos objets !)
	if (!$e['edition'] and in_array($table, lire_config('subdivisions/association_subdivision_objets', array()))) {
		$texte .= recuperer_fond('prive/objets/editer/liens', array(
			'table_source' => 'subdivisions',
			'objet' => $e['type'],
			'id_objet' => $flux['args'][$e['id_table_objet']],
	        'editable'=>autoriser('associersubdivisions',$e['type'],$flux['args'][$e['id_table_objet']])?'oui':'non'
		));
	}
	if ($texte) {
		if ($p = strpos($flux['data'], '<!--affiche_milieu-->')) {
			$flux['data'] = substr_replace($flux['data'], $texte, $p, 0);
		} else {
			$flux['data'] .= $texte;
		}
	}
	return $flux;
}


/**
 * Traitement supplémentaire pour le formulaire de la configuration
 *
 * @link https://programmer.spip.net/formulaire_traiter
 * @pipeline formulaire_traiter
 * @param  string $flux
 * @return string
 */

function subdivisions_formulaire_traiter($flux){
	// Traitement supplémentaire de la config
	if ($flux['args']['form'] == 'configurer_subdivisions' AND $flux['data']['message_ok']) {
		
		spip_log("@pipeline subdivisions_formulaire_traiter. tous = $tous"
				. " choix = " . print_r($choix,true)
				. " flux data = " . print_r($flux['data'],true),
				'subdivisions.' . _LOG_INFO_IMPORTANTE);

		// traitement par l'API
		include_spip('inc/apisubdivision');
		$blabla = apisubdivision_peuplement();	
		$flux['data']['message_ok'].= $blabla;	
	}
	return $flux;
}

